Additional interfaces
=====================

TorchIO features can be accessed through the standard Python interface,
the :ref:`Command-line tools <cli>` or the :ref:`3D Slicer GUI <gui>`.

.. _cli:
.. include:: cli.rst

.. _gui:
.. include:: slicer.rst
